/**
 * @file          Calendars View
 * @author        Wong Jia Hui (jiahui.wong@3ds.com)
 */
import { AppMP } from '../appmp';
import { ViewBase } from '../../libappbase/viewbase';
import { UIWaitSOP } from '../../libappsop/objectsop';
import { FormCommonCalendar } from '../forms/commoncalendar';
import { ButtonCapacitiesContextMenuItem } from '../actionbarpages/abp.data';
import { FormResourceCalendars } from '../forms/resourcecalendars';

export class ViewCalendar extends ViewBase implements UIWaitSOP {
  public readonly name = 'Calendars';
  public readonly viewPath = '"Data" > "Capacities" > "Calendars"';

  public formCommonCalendar = new FormCommonCalendar();
  public formResourceCalendars = new FormResourceCalendars();

  public async switchTo(): Promise<void> {
    const appMP = AppMP.getInstance();
    const abpData = appMP.abpData;

    // Click on Data action bar page
    await abpData.click();
    await abpData.btnCapacities.clickDropdownAndSelectMenu(ButtonCapacitiesContextMenuItem.Calendars.Name);

    await this.waitUILoaded();
  }

  public async waitUILoaded(): Promise<void> {
    await this.formCommonCalendar.waitUntilPresent();
    await this.formResourceCalendars.waitUntilPresent();
  }
}
